#! /bin/bash

if [[ -z "$SAXON" ]]; then
    SAXON=saxon
fi
# the stylesheet is either overloaded in the project, or the standard one
if [[ -f build/package-project.xsl ]]; then
    PACKAGER=build/package-project.xsl
else
    PACKAGER=http://expath.org/ns/packager/package-project.xsl
fi
# the stylesheet is either overloaded in the project, or the standard one
if [[ -f build/release-project.xsl ]]; then
    RELEASER=build/release-project.xsl
else
    RELEASER=http://expath.org/ns/packager/release-project.xsl
fi

if [[ -z "$1" ]]; then
    echo First option mandatory, got nothing;
    exit 1;
fi

if [[ "$1" != build && "$1" != test && "$1" != deploy && "$1" != release ]]; then
    echo Only build, test, deploy and release commands accepted, got \'$1\';
    exit 1;
fi

if [[ ! -z "$2" ]]; then
    echo Second option not accepted, got \'$2\';
    exit 1;
fi

if [[ ! -d build ]]; then
    echo Not a valid project, build/ does not exist;
    exit 1;
fi

if [[ ! -d src ]]; then
    echo Not a valid project, src/ does not exist;
    exit 1;
fi

if [[ ! -f build/project.xml ]]; then
    echo Not a valid project, build/project.xml does not exist;
    exit 1;
fi

if [[ "$1" == build ]]; then
    "$SAXON" --xslt -xsl:"$PACKAGER" -s:build/project.xml;
elif [[ "$1" == test ]]; then
    echo 'test' target not supported yet!;
elif [[ "$1" == deploy ]]; then
    echo 'deploy' target not supported yet!;
elif [[ "$1" == release ]]; then
    "$SAXON" --xslt -xsl:"$RELEASER" -s:build/project.xml;
fi
