<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:pp="http://expath.org/ns/packager"
                xmlns:file="http://expath.org/ns/file"
                xmlns:zip="http://expath.org/ns/zip"
                exclude-result-prefixes="#all"
                version="2.0">

   <xsl:import href="http://expath.org/ns/file.xsl"/>

   <!--
       See pp:zip-directory($dir).
       
       TODO: Add some other systems as well (Mercurial, Git, etc.)
   -->
   <xsl:param name="pp:directories-to-ignore" as="xs:string+" select="'.svn', 'CVS'"/>

   <xsl:variable name="pp:project" as="xs:anyURI"  select="resolve-uri('..', base-uri(.))"/>
   <xsl:variable name="src"        as="xs:anyURI"  select="resolve-uri('src/', $pp:project)"/>
   <xsl:variable name="build"      as="xs:anyURI"  select="resolve-uri('build/', $pp:project)"/>
   <xsl:variable name="sample"     as="xs:anyURI"  select="resolve-uri('sample/', $pp:project)"/>
   <xsl:variable name="abbrev"     as="xs:string"  select="/pp:package/@abbrev"/>
   <xsl:variable name="version"    as="xs:string"  select="/pp:package/@version"/>
   <xsl:variable name="prj-name"   as="xs:string"  select="concat($abbrev, '-', $version)"/>
   <xsl:variable name="is-web"     as="xs:boolean" select="
       exists(file:old-list($build)/file:file[@name eq 'expath-web.xml'])"/>
   <xsl:variable name="xar-name" as="xs:string"  select="
       concat($prj-name, if ( $is-web ) then '.xaw' else '.xar')"/>
   <xsl:variable name="xar"        as="xs:anyURI"  select="resolve-uri($xar-name, $build)"/>
   <xsl:variable name="release"    as="xs:anyURI"  select="
       resolve-uri(concat($prj-name, '.zip'), $build)"/>
   <xsl:variable name="pkg-ns"     as="xs:string"  select="'http://expath.org/ns/pkg'"/>

   <xsl:function name="pp:display-filename">
      <xsl:param name="file" as="xs:string"/>
      <xsl:sequence select="substring-after($file, $pp:project)"/>
   </xsl:function>

   <xsl:template match="file:dir" mode="zip-dir">
      <xsl:if test="not(@name = $pp:directories-to-ignore)">
         <zip:dir name="{ @name }">
            <xsl:apply-templates select="*" mode="zip-dir"/>
         </zip:dir>
      </xsl:if>
   </xsl:template>

   <xsl:template match="file:file" mode="zip-dir">
      <zip:entry name="{ @name }" src="{ @href }"/>
   </xsl:template>

   <!--
       Ignore directories with their name in pp:directories-to-ignore.
       Typically this parameter is a sequence of name like .svn, CVS, etc.
   -->
   <xsl:function name="pp:zip-directory" as="element(zip:dir)?">
      <xsl:param name="dir" as="xs:anyURI"/>
      <xsl:apply-templates select="file:old-list($dir)" mode="zip-dir"/>
   </xsl:function>

   <!--
       Same as pp:zip-directory(), except it does not copy $dir itself,
       only its content (its children files and dirs).
   -->
   <xsl:function name="pp:zip-directory-content" as="element()*">
      <xsl:param name="dir" as="xs:anyURI"/>
      <xsl:apply-templates select="file:old-list($dir)/*" mode="zip-dir"/>
   </xsl:function>

</xsl:stylesheet>
